@@ -368,18 +368,18 @@ data:extend({
         type = "instant",
         target_effects =
         {
-          {
-            type = "set-tile",
-            tile_name = "nuclear-ground",
-            radius = 12,
-            apply_projection = true,
-            tile_collision_mask = { layers={water_tile=true} }
-          },
-          {
+          { -- Destroy cliffs before changing tiles (so the cliff achievement works)
             type = "destroy-cliffs",
             radius = 9,
             explosion_at_trigger = "explosion"
           },
+          -- Explosion entities for other surface-specific effects are added here
+          {
+            type = "create-entity",
+            check_buildability = true,
+            -- This entity can have surface conditions
+            entity_name = "nuke-effects-nauvis"
+          },
           {
             type = "create-entity",
             entity_name = "nuke-explosion"
@@ -398,19 +398,13 @@ data:extend({
             type = "play-sound",
             sound = sounds.nuclear_explosion(0.9),
             play_on_target_position = false,
-            -- min_distance = 200,
             max_distance = 1000,
-            -- volume_modifier = 1,
-            audible_distance_modifier = 3
           },
           {
             type = "play-sound",
             sound = sounds.nuclear_explosion_aftershock(0.4),
             play_on_target_position = false,
-            -- min_distance = 200,
             max_distance = 1000,
-            -- volume_modifier = 1,
-            audible_distance_modifier = 3
           },
           {
             type = "damage",
